// Author: Antonio Navarro
// URL: http://www.thingiverse.com/AntonioNav/
//
// Licencia: CC BY-SA 3.0
//  http://creativecommons.org/licenses/by-sa/3.0/
//
// You need 3 M3 screws 25mm long
//

use <Includes/nuts_and_bolts.scad>
use <Includes/roundCornersCube.scad>

screw_long=25;

$fn=50;

//***********************************************************//
//***** Use 'to_print_part1' and 'to_print_part2' ***********//
//***** for generate stl files.                   ***********//

to_show();
//to_print_part1();
//to_print_part2();

module to_show(){
	color("orange"){
		front_support();
		bearing_608zz();
		bolts(screw_long);
	}
	color("green"){
		y_idler();
		adjustable_base(screw_long);
	}
}

module to_print(){
	to_print_part1();
	translate([30,0,0])
		to_print_part2();	
}

module to_print_part1(){
	rotate([90,0,0])
	translate([0,-3,0])
		y_idler();
}

module to_print_part2(){
	desp=screw_long-6;
	rotate([90,0,0])
		translate([0,desp,0])
			adjustable_base(screw_long);
}

module adjustable_base(long=10){

	long_guides=long-11;
		
		translate([0,-long_guides,0]){	
			difference(){		
				rotate([90,0,0])
					translate([0,0,5/2])
						roundCornersCube(25,30,5,5);
				bolt_holes();
			}
			guides(long_guides+3);
		}
}

module guides(long=10){
		translate([6.2,long/2-0.1,10.5])
			rotate([90,0,0])
				roundCornersCube(3,6,long,1);
		translate([-6.2,long/2-0.1,10.5])
			rotate([90,0,0])
				roundCornersCube(3,6,long,1);
		translate([6.2,long/2-0.1,-10.5])
			rotate([90,0,0])
				roundCornersCube(3,6,long,1);
		translate([-6.2,long/2-0.1,-10.5])
			rotate([90,0,0])
				roundCornersCube(3,6,long,1);
}

module bolt_holes(){

	metrica=3;
	long=10;

	translate([6.2,-3,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
		}
	translate([-6.4,-3,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
		}

	translate([0,0,0])
		rotate([90,0,0])
			nutHole(metrica);
	rotate([-90,0,0]){	
		translate([0,0,-10])
			boltHole(metrica, length=long);
		}
}


module y_idler(){

	difference(){
		y_idler_base();
		bearing_608zz(4);
		bolt_nuts();
		axis();
	}
}

module y_idler_base(){

	union(){
		difference(){
			rotate([0,90,0])
				round_cube_base();
			translate([0,-17.5+2.9,0])
				cube([25,35,50], center=true);
		}
	}
}

module round_cube_base(){
	
	alt=18;

	hull(){
		translate([-11,20,0])
			cylinder(r=8, h=alt, center=true);
		translate([16,17,0])
			cylinder(r=3, h=alt, center=true);
		translate([-11,-20,0])
			cylinder(r=8, h=alt, center=true);
		translate([11,-20,0])
			cylinder(r=8, h=alt, center=true);
	}
}

module bolt_nuts(){
	metrica=3;
	long=17;

		translate([6.2,-10,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
				translate([0,0,15])
						nutHole(metrica);
				translate([2,0,15])
						nutHole(metrica);
		}
		translate([-6.4,-10,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
				translate([0,0,15])
						nutHole(metrica);
				translate([-2,0,15])
						nutHole(metrica);
		}
}

module bolts(long=25){
	metrica=3;

//la posición de la tuerca son 5 y su grosor son 3
	pos=long-5-3;

		translate([6.2,-pos,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
		}
		translate([-6.4,-pos,0])
		rotate([-90,0,0]){
				boltHole(metrica, length=long);
		}
}

module front_support(){
	translate([-140.5,0,32])
			rotate([-90,0,0])
				linear_extrude(height=3)
					import("./Includes/Frontal_y_Trasero.dxf");
}

module bearing_608zz(gap=0){

	translate([0,20,12])
		rotate([0,90,0])
			difference(){
				cylinder(r=11+gap, h=8+gap, center=true);
				cylinder(r=4, h=9, center=true);
	}
}

module axis(){
	translate([0,20,12])
		rotate([0,90,0])
			cylinder(r=4.1, h=20, center=true);
}

module y_idler_steel(){

		translate([4.7,314,-243])
			rotate([0,-90,180])
				linear_extrude(height=3)
					import("./Includes/Soporte_idler_eje_Y.dxf");

		translate([-7.9,314,-243])
			rotate([0,-90,180])
				linear_extrude(height=3)
					import("./Includes/Soporte_idler_eje_Y.dxf");
}

